@@ -20,7 +20,7 @@ namespace PdfMod.Core
 {
 	public class Defines
 	{
-		public const string VERSION = "0.8.1";
-		public const string PREFIX = "/usr/local";
+		public const string VERSION = "0.8.2";
+		public const string PREFIX = "/usr";
 	}
 }
